import { Command as CommandBase } from '@oclif/command';
import request from 'request';
import { ProgressCallback } from './progress';
/**
 * Command constructor.
 */
export declare abstract class Command extends CommandBase {
    /**
     * Init function.
     */
    init(): Promise<any>;
    /**
     * Check if the shell is interactive.
     *
     * @return True if interactive shell, else false.
     */
    protected _isInteractive(): boolean;
    /**
     * Init a request object with the specified timeout.
     *
     * @param timeout Timeout duraction in miliseconds.
     * @return Request object.
     */
    protected _initRequest(timeout?: number): request.RequestAPI<request.Request, request.CoreOptions, request.RequiredUriUrl>;
    /**
     * Read input file to list all URL's line by line.
     *
     * @param filepath Input file.
     * @return URL list.
     */
    protected _readInputFile(filepath: string): Promise<string[]>;
    /**
     * Transfer seconds human readable.
     *
     * @param ms Miliseconds passed or null.
     * @return Formatted string.
     */
    protected _transferSecondsHuman(ms: number | null): string;
    /**
     * Transfer bytes human readable.
     *
     * @param size Byte size.
     * @return Formatted string.
     */
    protected _transferBytesHuman(size: number): string;
    /**
     * Init data transfer progress output function.
     *
     * @return Progress update callback function.
     */
    protected _transferProgressOutputInit(): ProgressCallback;
    /**
     * Clear data transfer progress output after.
     */
    protected _transferProgressOutputAfter(): void;
}
