/// <reference types="node" />
import { flags } from '@oclif/command';
import { WriteStream } from 'fs-extra';
import request from 'request';
import { Command } from '../command';
/**
 * Download command.
 */
export default class Download extends Command {
    /**
     * Aliases.
     */
    static readonly aliases: string[];
    /**
     * Description.
     */
    static description: string;
    /**
     * Examples.
     */
    static examples: never[];
    /**
     * Flags.
     */
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        output: flags.IOptionFlag<string | undefined>;
        dir: flags.IOptionFlag<string | undefined>;
        input: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        mtime: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        timeout: import("@oclif/parser/lib/flags").IOptionFlag<number>;
        update: import("@oclif/parser/lib/flags").IOptionFlag<number>;
    };
    /**
     * Arguments.
     */
    static args: {
        name: string;
        required: boolean;
        description: string;
    }[];
    /**
     * Handler.
     */
    run(): Promise<void>;
    /**
     * Handle an individual source.
     *
     * @param source The source.
     * @param outdir Output dir.
     * @param outfile Output files.
     * @param updateInterval Update interval.
     * @param req Request object.
     */
    protected _handleSource(source: string, outdir: string, outfile: string, mtime: boolean, updateInterval: number, req: typeof request): Promise<void>;
    /**
     * Download file to a file stream.
     *
     * @param file File stream.
     * @param url Download URL.
     * @param req Request object.
     * @param resume Resume offset.
     * @return Stream object and a complete promise.
     */
    protected _download(file: WriteStream, url: string, req: typeof request, resume: number): {
        stream: request.Request;
        complete: Promise<void>;
    };
    /**
     * Get a partial name from filename.
     *
     * @param filename The filename.
     * @return Partial name.
     */
    protected _partialFilename(filename: string): string;
}
