"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _command = require("@oclif/command");

var _zsExtract = require("zs-extract");

var _constants = require("../constants");

var _command2 = require("../command");

const jsonE = v => JSON.stringify(v);
/**
 * Extract command.
 */


class Extract extends _command2.Command {
  /**
   * Aliases.
   */

  /**
   * Description.
   */

  /**
   * Examples.
   */

  /**
   * Flags.
   */

  /**
   * Arguments.
   */

  /**
   * Handler.
   */
  async run() {
    // tslint:disable-next-line: no-unused
    const {
      args,
      flags
    } = this.parse(Extract);
    const source = args.source;
    const format = flags.format;
    const timeout = flags.timeout;
    const isJSON = format === 'json';
    const sources = flags.input ? await this._readInputFile(source) : [source];

    const req = this._initRequest(timeout * 1000);

    let errors = false;

    if (isJSON) {
      this.log('[');
    }

    for (let i = 0; i < sources.length; i++) {
      const source = sources[i];

      if (isJSON) {
        this.log('  {');
      } else if (i) {
        this.log('');
      }

      try {
        await this._handleSource(source, req, format);
      } catch (err) {
        errors = true;
        const error = String(err);

        if (isJSON) {
          this.log(`    "error": ${jsonE(error)}`);
        } else {
          this.log(`error: ${error}`);
        }
      }

      if (isJSON) {
        this.log('  }' + (i + 1 === sources.length ? '' : ','));
      }
    }

    if (isJSON) {
      this.log(']');
    }

    if (errors) {
      this.exit(1);
    }
  }
  /**
   * Handle an individual source.
   *
   * @param source The source.
   * @param req Request object.
   * @param format Output format.
   */


  async _handleSource(source, req, format) {
    const isJSON = format === 'json';

    if (isJSON) {
      this.log(`    "source": ${jsonE(source)},`);
    } else {
      this.log(`source: ${source}`);
    }

    const {
      download,
      filename
    } = await (0, _zsExtract.extract)(source, req);

    if (isJSON) {
      this.log(`    "download": ${jsonE(download)},`);
      this.log(`    "filename": ${jsonE(filename)}`);
    } else {
      this.log(`download: ${download}`);
      this.log(`filename: ${filename || ''}`);
    }
  }

}

exports.default = Extract;
Extract.aliases = ['ex', 'e'];
Extract.description = 'extract data about download';
Extract.examples = [];
Extract.flags = {
  help: _command.flags.help({
    char: 'h'
  }),
  format: _command.flags.string({
    char: 'f',
    description: 'output format',
    options: ['text', 'json'],
    default: 'text'
  }),
  input: _command.flags.boolean({
    char: 'i',
    description: 'source is input file with a URL on each line'
  }),
  timeout: _command.flags.integer({
    char: 't',
    description: 'request timeout in seconds',
    default: _constants.DEFAULT_TIMEOUT
  })
};
Extract.args = [{
  name: 'source',
  required: true,
  description: 'source to extract from'
}];
//# sourceMappingURL=extract.js.map
