"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.divmod = divmod;
exports.parseDate = parseDate;
exports.env = env;
exports.envTrue = envTrue;
exports.fstat = fstat;
exports.readInputFile = readInputFile;
exports.dateHumanTimestamp = dateHumanTimestamp;
exports.pipelineP = void 0;

var _stream = require("stream");

var _util = require("util");

var _fsExtra = require("fs-extra");

var _dateformat = _interopRequireDefault(require("dateformat"));

const pipelineP = (0, _util.promisify)(_stream.pipeline);
/**
 * Integer division with remained.
 *
 * @param v Value.
 * @param d Divisor.
 * @return Integer divided and remained.
 */

exports.pipelineP = pipelineP;

function divmod(v, d) {
  return [Math.floor(v / d), v % d];
}
/**
 * Parse date or return null is not valid.
 *
 * @param str Date string.
 * @return Date object or null.
 */


function parseDate(str) {
  const d = new Date(str);
  const t = d.getTime(); // Test if the time is NaN (NaN !== NaN).
  // tslint:disable-next-line: ter-no-self-compare

  return t === t ? d : null;
}
/**
 * Get environment variable value.
 *
 * @param name Environment name.
 * @return String value or null.
 */


function env(name) {
  const v = process.env[name];
  return v === undefined ? null : v;
}
/**
 * Check if the environment variable value is true.
 *
 * @param name Environment name.
 * @return String value is a true-like value.
 */


function envTrue(name) {
  const v = env(name);
  return v && /^(1|true|yes)$/i.test(v);
}
/**
 * Stat path or return null if path does not exist.
 *
 * @param filepath File path.
 * @return Stat object or null.
 */


async function fstat(filepath) {
  try {
    return await (0, _fsExtra.stat)(filepath);
  } catch (err) {// Ignore it.
  }

  return null;
}
/**
 * Read input file to list all URL's line by line.
 *
 * @param filepath Input file.
 * @return URL list.
 */


async function readInputFile(filepath) {
  const r = [];
  const data = await (0, _fsExtra.readFile)(filepath, 'utf8');
  const lines = data.split(/[\r\n]+/);

  for (const line of lines) {
    const s = line.trim();

    if (/^https?:\/\//i.test(s)) {
      r.push(s);
    }
  }

  return r;
}
/**
 * Format date for human readable timestamps.
 *
 * @param date Date object or null.
 * @return Date string.
 */


function dateHumanTimestamp(date = null) {
  const d = date || new Date();
  return (0, _dateformat.default)(d, 'yyyy-mm-dd h:MM:ss');
}
//# sourceMappingURL=util.js.map
