import { pipeline } from 'stream';
import { promisify } from 'util';
import { readFile, stat } from 'fs-extra';
import dateformat from 'dateformat';
export const pipelineP = promisify(pipeline);
/**
 * Integer division with remained.
 *
 * @param v Value.
 * @param d Divisor.
 * @return Integer divided and remained.
 */

export function divmod(v, d) {
  return [Math.floor(v / d), v % d];
}
/**
 * Parse date or return null is not valid.
 *
 * @param str Date string.
 * @return Date object or null.
 */

export function parseDate(str) {
  const d = new Date(str);
  const t = d.getTime(); // Test if the time is NaN (NaN !== NaN).
  // tslint:disable-next-line: ter-no-self-compare

  return t === t ? d : null;
}
/**
 * Get environment variable value.
 *
 * @param name Environment name.
 * @return String value or null.
 */

export function env(name) {
  const v = process.env[name];
  return v === undefined ? null : v;
}
/**
 * Check if the environment variable value is true.
 *
 * @param name Environment name.
 * @return String value is a true-like value.
 */

export function envTrue(name) {
  const v = env(name);
  return v && /^(1|true|yes)$/i.test(v);
}
/**
 * Stat path or return null if path does not exist.
 *
 * @param filepath File path.
 * @return Stat object or null.
 */

export async function fstat(filepath) {
  try {
    return await stat(filepath);
  } catch (err) {// Ignore it.
  }

  return null;
}
/**
 * Read input file to list all URL's line by line.
 *
 * @param filepath Input file.
 * @return URL list.
 */

export async function readInputFile(filepath) {
  const r = [];
  const data = await readFile(filepath, 'utf8');
  const lines = data.split(/[\r\n]+/);

  for (const line of lines) {
    const s = line.trim();

    if (/^https?:\/\//i.test(s)) {
      r.push(s);
    }
  }

  return r;
}
/**
 * Format date for human readable timestamps.
 *
 * @param date Date object or null.
 * @return Date string.
 */

export function dateHumanTimestamp(date = null) {
  const d = date || new Date();
  return dateformat(d, 'yyyy-mm-dd h:MM:ss');
}
//# sourceMappingURL=util.mjs.map
